@@ -2,7 +2,7 @@
 //
 // Abstract base class for streaming server connections.
 //
-//   (C) Copyright 2014-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2014-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -44,6 +44,7 @@ Connector::Connector(const QString &mimetype,QObject *parent)
   conn_stream_genre="unknown";
   conn_stream_public=true;
   conn_stream_metadata_enabled=true;
+  conn_dump_headers=false;
   conn_stream_metadata="";
   conn_host_hostname="";
   conn_host_port=0;
@@ -114,7 +115,12 @@ void Connector::setServerUrl(const QUrl &url)
   conn_server_url=url;
   uint16_t port=conn_server_url.port();
   if(port==65535) {
-    conn_server_url.setPort(DEFAULT_SERVER_PORT);
+    if(conn_server_url.scheme().toLower()=="https") {
+      conn_server_url.setPort(443);
+    }
+    else {
+      conn_server_url.setPort(DEFAULT_SERVER_PORT);
+    }
   }
   if(conn_server_url.path().isEmpty()) {
     conn_server_url.setPath("/");
@@ -195,10 +201,21 @@ void Connector::setStreamMetadataEnabled(bool state)
 }
 
 
+bool Connector::dumpHeaders() const
+{
+  return conn_dump_headers;
+}
+
+
+void Connector::setDumpHeaders(bool state)
+{
+  conn_dump_headers=state;
+}
+
+
 void Connector::startMetadata()
 {
   emit metadataReceived(0,&conn_metadata);
-  conn_metadata.processed();
   conn_start_metadata=true;
 }
 
@@ -235,6 +252,7 @@ void Connector::connectToServer()
 
 void Connector::stop()
 {
+  disconnectFromHostConnector();
   setConnected(false);
 }
 
@@ -486,8 +504,7 @@ QDateTime Connector::xmlTimestamp(const QString &str)
     }
   }
   if(date.isValid()&&time.isValid()) {
-    ret=QDateTime(date,time);
-    ret.addSecs(Connector::timezoneOffset()-tz_offset);
+    ret=QDateTime(date,time).addSecs(Connector::timezoneOffset()-tz_offset);
   }
 
   return ret;
@@ -561,14 +578,13 @@ void Connector::setConnected(bool state)
 }
 
 
-void Connector::setMetadataField(uint64_t bytes,MetaEvent::Field field,
-				 const QVariant &value)
+void Connector::setMetadataField(uint64_t bytes,const QString &key,
+				 const QString &str)
 {
-  conn_metadata.setField(field,value);
+  conn_metadata.setField(key,str);
 
   if(conn_start_metadata) {
     emit metadataReceived(bytes,&conn_metadata);
-    conn_metadata.processed();
   }
 }
 
