@@ -18,10 +18,23 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#ifndef WIN32
 #include <syslog.h>
+#endif  // WIN32
 
 #include <QString>
 
+#ifdef WIN32
+#define	LOG_EMERG	0	/* system is unusable */
+#define	LOG_ALERT	1	/* action must be taken immediately */
+#define	LOG_CRIT	2	/* critical conditions */
+#define	LOG_ERR		3	/* error conditions */
+#define	LOG_WARNING	4	/* warning conditions */
+#define	LOG_NOTICE	5	/* normal but significant condition */
+#define	LOG_INFO	6	/* informational */
+#define	LOG_DEBUG	7	/* debug-level messages */
+#endif  // WIN32
+
 #define LOG_TO_STDERR 0
 #define LOG_TO_SYSLOG 1
 #define LOG_TO_STDOUT 2
