@@ -2,7 +2,7 @@
 //
 // glassplayer(1) Audio Encoder
 //
-//   (C) Copyright 2014-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2014-2021 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -56,7 +56,6 @@ MainObject::MainObject(QObject *parent)
   sir_meter_data=false;
   sir_server_id=NULL;
   sir_first_stats=true;
-  disable_stream_metadata=false;
   bool ok=false;
 
   audio_device_type=DEFAULT_AUDIO_DEVICE;
@@ -65,10 +64,12 @@ MainObject::MainObject(QObject *parent)
   list_devices=false;
   pregap=0;
   sir_stats_out=false;
+  sir_metadata_out=false;
+  sir_json=false;
   server_type=Connector::XCastServer;
+  dump_headers=false;
 
-  CmdSwitch *cmd=
-    new CmdSwitch(qApp->argc(),qApp->argv(),"glassplayer",GLASSPLAYER_USAGE);
+  CmdSwitch *cmd=new CmdSwitch("glassplayer",GLASSPLAYER_USAGE);
   if(getenv("HOME")!=NULL) {
     cmd->addOverlay(getenv("HOME")+QString("/.glassplayerrc"));
   }
@@ -87,14 +88,18 @@ MainObject::MainObject(QObject *parent)
 	}
       }
     }
-    if(cmd->key(i)=="--disable-stream-metadata") {
-      disable_stream_metadata=true;
-      cmd->setProcessed(i,true);
-    }
     if(cmd->key(i)=="--dump-bitstream") {
       dump_bitstream=true;
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--dump-headers") {
+      dump_headers=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--json") {
+      sir_json=true;
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--list-codecs") {
       list_codecs=true;
       cmd->setProcessed(i,true);
@@ -103,6 +108,10 @@ MainObject::MainObject(QObject *parent)
       list_devices=true;
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--metadata-out") {
+      sir_metadata_out=true;
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--meter-data") {
       sir_meter_data=true;
       cmd->setProcessed(i,true);
@@ -114,7 +123,7 @@ MainObject::MainObject(QObject *parent)
     if(cmd->key(i)=="--pregap") {
       pregap=cmd->value(i).toUInt(&ok);
       if(!ok) {
-	fprintf(stderr,"glassplayer: unvalid argument to --pregap\n");
+	fprintf(stderr,"glassplayer: invalid argument to --pregap\n");
 	exit(GLASS_EXIT_ARGUMENT_ERROR);
       }
       cmd->setProcessed(i,true);
@@ -176,6 +185,11 @@ MainObject::MainObject(QObject *parent)
     exit(0);
   }
 
+  //
+  // JSON Generator
+  //
+  sir_json_engine=new JsonEngine();
+
   //
   // Starvation Watchdog
   //
@@ -228,8 +242,10 @@ MainObject::MainObject(QObject *parent)
 void MainObject::serverTypeFoundData(Connector::ServerType type,
 				     const QString &mimetype,const QUrl &url)
 {
+  //  printf("serverTypeFound(%d,%s,%s)\n",type,
+  //  	 mimetype.toUtf8().constData(),url.toString().toUtf8().constData());
   sir_connector=ConnectorFactory(type,mimetype,this);
-  sir_connector->setStreamMetadataEnabled(!disable_stream_metadata);
+  sir_connector->setStreamMetadataEnabled(sir_metadata_out);
   connect(sir_connector,SIGNAL(connected(bool)),
 	  this,SLOT(serverConnectedData(bool)));
   sir_connector->setServerUrl(url);
@@ -237,6 +253,7 @@ void MainObject::serverTypeFoundData(Connector::ServerType type,
   sir_connector->setServerPassword(sir_password);
   sir_connector->setPublicUrl(server_url);
   sir_connector->setPostData(post_data);
+  sir_connector->setDumpHeaders(dump_headers);
   sir_connector->connectToServer();
 }
 
@@ -350,24 +367,25 @@ void MainObject::metadataReceivedData(MetaEvent *e)
   QStringList values;
 
   sir_meta_event=*e;
-  for(unsigned i=0;i<MetaEvent::LastField;i++) {
-    MetaEvent::Field f=(MetaEvent::Field)i;
-    if(e->isChanged(f)) {
-      if(global_log_verbose) {
-	Log(LOG_INFO,e->fieldText(f)+": "+e->field(f).toString());
-      }
-      if(sir_stats_out) {
-	hdrs.push_back("Metadata|"+e->fieldText(f));
-	values.push_back(e->field(f).toString());
-      }
+
+  if(global_log_verbose) {
+    QStringList keys=e->fieldKeys();
+    for(int i=0;i<keys.size();i++) {
+      Log(LOG_INFO,keys.at(i)+": "+e->field(keys.at(i)));
     }
   }
-  if(hdrs.size()>0) {
-    for(int i=0;i<hdrs.size();i++) {
-      printf("%s: %s\n",(const char *)hdrs[i].toUtf8(),
-	     (const char *)values[i].toUtf8());
+  if(sir_metadata_out) {
+    if(sir_json) {
+      sir_json_engine->addEvents(e->exportFields());
+      printf("%s\n",(const char *)sir_json_engine->generate().toUtf8());
+      sir_json_engine->clear();
+    }
+    else {
+      QString data=e->exportFields();
+      data.replace("\r","\\r");
+      data.replace("\n","\\n");
+      printf("%s\n",(const char *)e->exportFields().toUtf8());
     }
-    printf("\n");
     fflush(stdout);
   }
 }
@@ -405,11 +423,20 @@ void MainObject::statsData()
   if(sir_audio_device!=NULL) {
     sir_audio_device->getStats(&hdrs,&values,sir_first_stats);
   }
-  for(int i=0;i<hdrs.size();i++) {
-    printf("%s: %s\n",(const char *)hdrs[i].toUtf8(),
-	   (const char *)values[i].toUtf8());
+  if(sir_json) {
+    for(int i=0;i<hdrs.size();i++) {
+      sir_json_engine->addEvents(hdrs.at(i)+": "+values.at(i));
+    }
+    printf("%s\n",(const char *)sir_json_engine->generate().toUtf8());
+    sir_json_engine->clear();
+  }
+  else {
+    for(int i=0;i<hdrs.size();i++) {
+      printf("%s: %s\n",(const char *)hdrs[i].toUtf8(),
+	     (const char *)values[i].toUtf8());
+    }
+    printf("\n");
   }
-  printf("\n");
   fflush(stdout);
   sir_first_stats=false;
 }
@@ -418,17 +445,26 @@ void MainObject::statsData()
 void MainObject::meterData()
 {
   int lvls[MAX_AUDIO_CHANNELS];
+  QString hex;
 
   sir_audio_device->meterLevels(lvls);
   switch(sir_codec->channels()) {
   case 1:
-    printf("ME %04X%04X\n",0xFFFF&lvls[0],0xFFFF&lvls[0]);
+    hex=QString().sprintf("ME %04X%04X",0xFFFF&lvls[0],0xFFFF&lvls[0]);
     break;
 
   case 2:
-    printf("ME %04X%04X\n",0xFFFF&lvls[0],0xFFFF&lvls[1]);
+    hex=QString().sprintf("ME %04X%04X",0xFFFF&lvls[0],0xFFFF&lvls[1]);
     break;
   }
+  if(sir_json) {
+    sir_json_engine->addEvent("Meter|Update: "+hex);
+    printf("%s\n",(const char *)sir_json_engine->generate().toUtf8());
+    sir_json_engine->clear();
+  }
+  else {
+    printf("%s\n",(const char *)hex.toUtf8());
+  }
   fflush(stdout);
 }
 
@@ -441,15 +477,16 @@ void MainObject::exitData()
 	RunScript(sir_server_script_down);
       }
     }
-    if(sir_audio_device!=NULL) {
-      sir_audio_device->stop();
-      delete sir_audio_device;
+    if(sir_connector!=NULL) {
+      sir_connector->stop();
+      delete sir_connector;
     }
     if(sir_codec!=NULL) {
       delete sir_codec;
     }
-    if(sir_connector!=NULL) {
-      delete sir_connector;
+    if(sir_audio_device!=NULL) {
+      sir_audio_device->stop();
+      delete sir_audio_device;
     }
     exit(0);
   }
