@@ -1,9 +1,8 @@
-
 // glassplayer.h
 //
 // glassplayer(1) Audio Player
 //
-//   (C) Copyright 2014-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2014-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,6 +29,7 @@
 #include "audiodevice.h"
 #include "codec.h"
 #include "connector.h"
+#include "jsonengine.h"
 #include "ringbuffer.h"
 #include "serverid.h"
 
@@ -60,11 +60,12 @@ class MainObject : public QObject
   Connector::ServerType server_type;
   AudioDevice::Type audio_device_type;
   QUrl server_url;
-  bool disable_stream_metadata;
   bool dump_bitstream;
   unsigned pregap;
   QString post_data;
   bool sir_stats_out;
+  bool sir_json;
+  bool sir_metadata_out;
   QString sir_server_script_up;
   QString sir_server_script_down;
   QString sir_user;
@@ -73,6 +74,7 @@ class MainObject : public QObject
   QStringList device_values;
   bool list_codecs;
   bool list_devices;
+  bool dump_headers;
   Ringbuffer *sir_ring;
   Codec *sir_codec;
   Connector *sir_connector;
@@ -84,6 +86,7 @@ class MainObject : public QObject
   bool sir_first_stats;
   bool sir_meter_data;
   QTimer *sir_meter_timer;
+  JsonEngine *sir_json_engine;
 };
 
 
