@@ -2,7 +2,7 @@
 //
 // glassplayergui(1) Audio Receiver front end
 //
-//   (C) Copyright 2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2016-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,6 +21,7 @@
 #ifndef GLASSGUIPLAYER_H
 #define GLASSGUIPLAYER_H
 
+#include <QJsonObject>
 #include <QLabel>
 #include <QMainWindow>
 #include <QProcess>
@@ -28,9 +29,11 @@
 #include <QStringList>
 
 #include "glasslimits.h"
+#include "jsonparser.h"
 #include "playmeter.h"
 #include "statsdialog.h"
 
+#define GLASSPLAYERGUI_METADATA_FIELD_QUAN 4
 #define GLASSPLAYERGUI_USAGE "[options]\n"
 
 class MainWidget : public QMainWindow
@@ -42,10 +45,11 @@ class MainWidget : public QMainWindow
 
  private slots:
   void showStatsData();
-  void processStart(const QString &url);
+  void processStart(const QString &url, const QStringList &jackd_args);
   void processReadyReadData();
   void processFinishedData(int exit_code,QProcess::ExitStatus status);
   void processErrorData(QProcess::ProcessError err);
+  void newJsonDocumentData(const QJsonDocument &doc);
   void logoProcessFinishedData(int exit_code,QProcess::ExitStatus status);
   void logoProcessErrorData(QProcess::ProcessError err);
 
@@ -54,25 +58,20 @@ class MainWidget : public QMainWindow
   void resizeEvent(QResizeEvent *e);
 
  private:
-  void ProcessStats(const QStringList &stats);
+  void ProcessMetadataUpdates(const QJsonObject &obj);
   void ProcessMeterUpdates(const QString &values);
-  void UpdateStat(const QString &category,const QString &param,
-		  const QString &value);
   void GetLogo(const QString &url);
   QLabel *gui_title_text;
-  QLabel *gui_name_label;
-  QLabel *gui_name_text;
-  QLabel *gui_description_label;
-  QLabel *gui_description_text;
-  QLabel *gui_channelurl_label;
-  QLabel *gui_channelurl_text;
-  QLabel *gui_genre_label;
-  QLabel *gui_genre_text;
+  QLabel *gui_metadata_labels[GLASSPLAYERGUI_METADATA_FIELD_QUAN];
+  QLabel *gui_metadata_texts[GLASSPLAYERGUI_METADATA_FIELD_QUAN];
   QLabel *gui_logo_label;
   QProcess *gui_player_process;
   QProcess *gui_logo_process;
+  JsonParser *gui_json_parser;
   QStringList gui_stats_list;
   QString gui_url;
+  QStringList jackd_args;
+  QString jackd_client_name;
   PlayMeter *gui_meters[MAX_AUDIO_CHANNELS];
   StatsDialog *gui_stats_dialog;
   QPushButton *gui_stats_button;
