@@ -2,7 +2,7 @@
 //
 // Stats viewer dialog
 //
-//   (C) Copyright 2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2016-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,15 @@
 StatsDialog::StatsDialog(QWidget *parent)
   : QDialog(parent)
 {
+  QFont label_font(font().family(),font().pointSize(),QFont::Bold);
+
+  stats_category_label=new QLabel(tr("View")+":",this);
+  stats_category_label->setFont(label_font);
+  stats_category_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+  stats_category_box=new ComboBox(this);
+  connect(stats_category_box,SIGNAL(activated(const QString &)),
+	  this,SLOT(categoryActivatedData(const QString &)));
+
   setWindowTitle("GlassPlayer - "+tr("Stream Statistics"));
 
   setMinimumSize(sizeHint());
@@ -31,7 +40,7 @@ StatsDialog::StatsDialog(QWidget *parent)
 
 QSize StatsDialog::sizeHint() const
 {
-  return QSize(400,480);
+  return QSize(540,550);
 }
 
 
@@ -40,9 +49,27 @@ void StatsDialog::update(const QString &category,const QString &param,
 {
   if(stats_panels[category]==NULL) {
     stats_panels[category]=new StatsPanel(category,this);
+    stats_panels.value(category)->hide();
     resizeEvent(NULL);
   }
-  stats_panels[category]->update(param,value);
+  stats_panels.value(category)->update(param,value);
+
+  if(!stats_category_box->contains(category)) {
+    stats_category_box->
+      insertItem(stats_category_box->count(),category,category);
+    if(stats_category_box->count()==1) {
+      categoryActivatedData(category);
+    }
+  }
+}
+
+
+void StatsDialog::categoryActivatedData(const QString &str)
+{
+  for(QMap<QString,StatsPanel *>::const_iterator it=stats_panels.begin();
+      it!=stats_panels.end();it++) {
+    it.value()->setVisible(it.key()==str);
+  }
 }
 
 
@@ -54,16 +81,14 @@ void StatsDialog::closeEvent(QCloseEvent *e)
 
 void StatsDialog::resizeEvent(QResizeEvent *e)
 {
-  int count=0;
   int w=size().width();
   int h=size().height();
 
-  for(std::map<QString,StatsPanel *>::const_iterator it=stats_panels.begin();
+  stats_category_label->setGeometry(10,2,95,20);
+  stats_category_box->setGeometry(110,2,200,20);
+
+  for(QMap<QString,StatsPanel *>::const_iterator it=stats_panels.begin();
       it!=stats_panels.end();it++) {
-    it->second->setGeometry(0,
-			    count*h/(stats_panels.size()),
-			    w,
-			    h/stats_panels.size());
-    count++;
+    it.value()->setGeometry(0,25,w,h-25);
   }
 }
