@@ -2,7 +2,7 @@
 //
 // Stats viewer section
 //
-//   (C) Copyright 2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2016-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,6 @@
 
 #include <map>
 
-#include <QLabel>
 #include <QString>
 #include <QStringList>
 #include <QTextEdit>
@@ -41,7 +40,6 @@ class StatsPanel : public QWidget
   void resizeEvent(QResizeEvent *e);
 
  private:
-  QLabel *stats_category_label;
   QTextEdit *stats_text;
   QString stats_category;
   std::map<QString,QString> stats_values;
